importFusionData in a list of fSet objects.
fSet-class offers various methods to extract information from the fSet objects.
The fusion names can be extracted with fusionName function.
The number of reads supporting a fusion event cam be extracted with the supportingReads function.Filtering:
The imported fusion list can be filtered using filterList
Annotation:
Oncofuse can be installed in chimera with the function oncofuseInstallation
Various information on the fusions location, on structural and functional domains affected by the fusion event as well as a prediction of the putative functional effect of the fusion on the cell can be obtained by using oncofuseRun.
chimeraSeqs generates the nucleotide sequence of a fusion transcript described in an fSet object. chimeraSeqSet does the same but on a list of fSet objects.
fusionPeptides allows to investigate if the fusion events generate also a fusion at protein level.
subreadRun allows to remap reads on the fused transcripts reconstructed with chimeraSeqs
Validation
GapFiller is a seed-and-extend local assembler capable to produce (in-silico) longer and highly accurate sequences from a collection of Next Generation Sequencing reads. It can be installed in chimera with the function gapfillerInstallation.
The function gapfillerRun allows to check if reads mapped by subreadRun over a fused transcript generated with chimeraSeqs are able to reconstruct by de novo assembly the fusion break-point.
Export
The function prettyPrint converts the information stored in a list of fSet objects in a dataframe structure that is saved as tab delimited file.
| Package: |
| chimera |
| Type: |
| Package |
| Version: |
| 1.0 |
| Date: |
| 2014-31-07 |
| License: |
| Artistic-2.0 |